@@ -1,7 +1,7 @@
 from config import config
 import psycopg2
 import pandas as pd
-import csv2raster as c2r
+from geoAnalytics import csv2raster as c2r
 import os
 import subprocess
 
